Coverage for pymend\docstring_parser\__init__.py: 100%

1"""Parse docstrings as per Sphinx notation."""

2

3 from .common import (

4 Docstring,

5 DocstringDeprecated,

6 DocstringExample,

7 DocstringMeta,

8 DocstringParam,

9 DocstringRaises,

10 DocstringReturns,

11 DocstringStyle,

12 DocstringYields,

13 ParseError,

14 RenderingStyle,

15)

16 from .parser import compose, parse

17 from .util import combine_docstrings

18

19 Style = DocstringStyle # backwards compatibility

20

21 __all__ = [

22 "parse",

23 "combine_docstrings",

24 "compose",

25 "ParseError",

26 "Docstring",

27 "DocstringMeta",

28 "DocstringParam",

29 "DocstringRaises",

30 "DocstringReturns",

31 "DocstringYields",

32 "DocstringDeprecated",

33 "DocstringExample",

34 "DocstringStyle",

35 "RenderingStyle",

36 "Style",

37]